==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/view/login.php <==
<?php
/**
 * Login page
 */

namespace RonPortal;

// Zrusi data prihlaseneho uzivatele
use Ron\Http\App;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;

unset($_SESSION['loginname']);
unset($_SESSION['loginpassword']);
  
require_once('appconstants.php');

global $enable_login_as;
global $copyrightYear;
global $appVersion;
global $appDate;
global $enableidlogin;

//$action = '?';
//if ( $_SERVER["QUERY_STRING"] && $_GET["menuid"] != "logout") {
//    $action = '?' . $_SERVER["QUERY_STRING"];
//}

$langStr = RonPortalSettings::getValue('preklady', 'cz;sk;eng');
$langs = $langStr ? explode(';', $langStr) : ['cz', 'sk', 'eng'];

?>
<!doctype html>
<html>
<head>
    <?php
    require('ron/apphead.php');
    require('view/apphead.php');
    ?>
</head>
<body class="bodylogin">

    <div class="loginpagecontent">
        <?php require('view/apptitle.php'); ?>

        <div class="topmenu" id="topmenu">
            <div class="appselect"></div>
            <ul class="langselect inline-list list-slash">
                <?php foreach ($langs as $lang) { ?>
                    <li id="lang_item_<?= $lang ?>" title="<?= TextManager::_('LANG_TITLE_' . strtolower($lang)) ?>">
                        <a href="?session@lang=<?= $lang ?>"><?= TextManager::_('LANG_' . strtolower($lang)) ?></a>
                    </li>
                <?php } ?>
            </ul>
        </div>

        <div class="container">
            <h2><?= TextManager::_('Prihlaseni_uzivatele') ?></h2>

            <div class="d-none errortext ie-only"><?=    StringUtils::fromUTF8('Prohlížeč Internet Explorer již není podporován! Použijte prosím jiný prohlížeč (například Edge, Chrome, Firefox)') ?></div>

            <?php if ( file_exists("_userloginpage.php") ) include("_userloginpage.php"); ?>
            <div id="login_page_info"><?= TextManager::_('Login_page_info') ?></div>

            <form name="loginform" method="post" <?= (isset($_GET["menuid"]) && ($_GET["menuid"] == "logout")) ? 'action="?"' : ''?>
                  data-ron-working-info="<?= StringUtils::htmlTextConvert(TextManager::_('Probiha_odesilani')) ?>">
                <input id="login_adblock"  type="hidden" name="adblock" value="1" /> <!-- vypne se javascriptem -->

                <div class="form small-form form-100 d-inline-block">
                    <div class="form-content">
                        <?php MessageManager::getInstance() ->showMessages(); ?>

                        <?php if (isset($enableidlogin)  &&  $enableidlogin) { // prihlasovani kartou ?>
                            <input type="hidden" class="rd-reader" data-ron-autosubmit="1" name="loginname" />
                            <div class="margin-all-2 padding-all-2 align-center">
                                    <?= TextManager::_('Prilozte_kartu') ?>
                                <!--
                                <div class="form-col form-col1 caption"><?= TextManager::_('Cislo_karty') ?></div>
                                <div class="form-col form-col2">
                                    <input type='password' class="form-control" autocomplete='off' name='loginname' size='20'>
                                    <input type='hidden' name='idlogin' value='1'>
                                </div>
                                -->
                            </div>

                        <?php } else { // prihlaseni pomoci jmena a hesla ?>
                            <div class="form-row">
                                <div class="form-col form-col1 caption"><?= TextManager::_('Login') ?></div>
                                <div class="form-col form-col2"><input type="text" class="form-control defaultfocus" name="loginname" id="loginname" size="20"></div>
                            </div>
                            <div class="form-row">
                                <div class="form-col form-col1 caption"><?= TextManager::_('Heslo') ?></div>
                                <div class="form-col form-col2"><input type="password" class="form-control" name="loginpassword" id="loginpassword" size="20"></div>
                            </div>
                        <?php } ?>

                    </div>

                    <?php if (!isset($enableidlogin)  ||  !$enableidlogin) { // pri prihlasovani kartou se nezobrazi tlacitka ?>
                    <div class="buttons">
                        <input type="submit" class="submitbutton" id="loginbutton" name="login" value=<?= TextManager::_('Vstup') ?>>
                    </div>
                    <?php } ?>
                </div>

            </form>

            <div id="nojs" class="errortext"><a href="script/nojs.html"><?= TextManager::_('Adblock_nebo_vypnuty_javascript') ?></a></div>
            <?php
                global $phpMinVersion;
                if (PHP_VERSION_ID < $phpMinVersion) { ?>
                <div class="errortext"><a href="https://www.php.net/supported-versions.php" target="_blank"><?= TextManager::_('PHP_stara_verze') ?></a></div>
            <?php } ?>
        </div>
    </div>

    <div class="footer fixed-md-bottom">
        <div class="copyright"> RON Software (c) 2007-<?= $copyrightYear ?></div>
        <div class="version"><?php if (!$enableidlogin) echo "<a href='verze.php' title='$appDate' target='_blank'>"; echo $appVersion; if (!$enableidlogin) echo "</a>"; ?></div>
    </div>

    <script>
        $(function () {
            if (window.neniAdblock) {
                $("#login_adblock").val("0");
            }
        });
    </script>

<?php App::getInstance() ->renderHtmlFooter(); ?>

</body>
</html>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/view/login.php <==
<?php
/**
 * Login page
 */

namespace RonPortal;

// Zrusi data prihlaseneho uzivatele
use Ron\Http\App;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;

unset($_SESSION['loginname']);
unset($_SESSION['loginpassword']);
  
require_once('appconstants.php');

global $enable_login_as;
global $copyrightYear;
global $appVersion;
global $appDate;
global $enableidlogin;

//$action = '?';
//if ( $_SERVER["QUERY_STRING"] && $_GET["menuid"] != "logout") {
//    $action = '?' . $_SERVER["QUERY_STRING"];
//}

$langStr = RonPortalSettings::getValue('preklady', 'cz;sk;eng');
$langs = $langStr ? explode(';', $langStr) : ['cz', 'sk', 'eng'];

?>
<!doctype html>
<html>
<head>
    <?php
    require('ron/apphead.php');
    require('view/apphead.php');
    ?>
</head>
<body class="bodylogin">

    <div class="loginpagecontent">
        <?php require('view/apptitle.php'); ?>

        <div class="topmenu" id="topmenu">
            <div class="appselect"></div>
            <ul class="langselect inline-list list-slash">
                <?php foreach ($langs as $lang) { ?>
                    <li id="lang_item_<?= $lang ?>" title="<?= TextManager::_('LANG_TITLE_' . strtolower($lang)) ?>">
                        <a href="?session@lang=<?= $lang ?>"><?= TextManager::_('LANG_' . strtolower($lang)) ?></a>
                    </li>
                <?php } ?>
            </ul>
        </div>

        <div class="container">
            <h2><?= TextManager::_('Prihlaseni_uzivatele') ?></h2>

            <div class="d-none errortext ie-only"><?=    StringUtils::fromUTF8('Prohlížeč Internet Explorer již není podporován! Použijte prosím jiný prohlížeč (například Edge, Chrome, Firefox)') ?></div>

            <?php if ( file_exists("_userloginpage.php") ) include("_userloginpage.php"); ?>
            <div id="login_page_info"><?= TextManager::_('Login_page_info') ?></div>

            <form name="loginform" method="post" <?= (isset($_GET["menuid"]) && ($_GET["menuid"] == "logout")) ? 'action="?"' : ''?>
                  data-ron-working-info="<?= StringUtils::htmlTextConvert(TextManager::_('Probiha_odesilani')) ?>">
                <input id="login_adblock"  type="hidden" name="adblock" value="1" /> <!-- vypne se javascriptem -->

                <div class="form small-form form-100 d-inline-block">
                    <div class="form-content">
                        <?php MessageManager::getInstance() ->showMessages(); ?>

                        <?php if (isset($enableidlogin)  &&  $enableidlogin) { // prihlasovani kartou ?>
                            <input type="hidden" class="rd-reader" data-ron-autosubmit="1" name="loginname" />
                            <div class="margin-all-2 padding-all-2 align-center">
                                    <?= TextManager::_('Prilozte_kartu') ?>
                            </div>

                        <?php } else { // prihlaseni pomoci jmena a hesla ?>
                            <div class="form-row">
                                <div class="form-col form-col1 caption"><?= TextManager::_('Login') ?></div>
                                <div class="form-col form-col2"><input type="text" class="form-control defaultfocus" name="loginname" id="loginname"></div>
                            </div>
                            <div class="form-row">
                                <div class="form-col form-col1 caption"><?= TextManager::_('Heslo') ?></div>
                                <div class="form-col form-col2"><input type="password" class="form-control" name="loginpassword" id="loginpassword"></div>
                            </div>
                        <?php } ?>

                    </div>

                    <?php if (!isset($enableidlogin)  ||  !$enableidlogin) { // pri prihlasovani kartou se nezobrazi tlacitka ?>
                    <div class="buttons">
                        <input type="submit" class="submitbutton" id="loginbutton" name="login" value=<?= TextManager::_('Vstup') ?>>
                    </div>
                    <?php } ?>
                </div>

            </form>

            <div id="nojs" class="errortext"><a href="script/nojs.html"><?= TextManager::_('Adblock_nebo_vypnuty_javascript') ?></a></div>
            <?php
                global $phpMinVersion;
                if (PHP_VERSION_ID < $phpMinVersion) { ?>
                <div class="errortext"><a href="https://www.php.net/supported-versions.php" target="_blank"><?= TextManager::_('PHP_stara_verze') ?></a></div>
            <?php } ?>
        </div>
    </div>

    <div class="footer fixed-md-bottom">
        <div class="copyright"> RON Software (c) 2007-<?= $copyrightYear ?></div>
        <div class="version"><?php if (!$enableidlogin) echo "<a href='verze.php' title='$appDate' target='_blank'>"; echo $appVersion; if (!$enableidlogin) echo "</a>"; ?></div>
    </div>

    <script>
        $(function () {
            if (window.neniAdblock) {
                $("#login_adblock").val("0");
            }
        });
    </script>

<?php App::getInstance() ->renderHtmlFooter(); ?>

</body>
</html>
